@@ -1,6 +1,6 @@
 package Bundle::AndyA;
 
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 1;
 
@@ -182,8 +182,6 @@ Parallel::Iterator
 
 Path::Class
 
-Path::Class::Each
-
 Perl::Tidy
 
 Perl::Version
@@ -242,6 +240,8 @@ WWW::Plurk
 
 XML::Descent
 
+XML::Twig
+
 YAML
 
 attributes
